@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import warnings
 
 from logzero import logger
@@ -7,17 +6,19 @@ from chaoslib.activity import get_all_activities_in_experiment
 from chaoslib.types import Experiment
 
 __all__ = ["warn_about_deprecated_features", "warn_about_moved_function"]
-DeprecatedDictArgsMessage = \
-    "Process arguments should now be a list to keep the ordering "\
-    "of the arguments. Dictionary arguments are deprecated for "\
+DeprecatedDictArgsMessage = (
+    "Process arguments should now be a list to keep the ordering "
+    "of the arguments. Dictionary arguments are deprecated for "
     "process activities."
-DeprecatedVaultMissingPathMessage = \
-    "Vault secrets must now specify the `path` property. The `key` property " \
-    "is now a key of a Vault secret rather than the actual path. For " \
-    "instance: " \
-    "{'my-key': {'type': 'vault', 'key': 'foo'}} " \
-    "now becomes: " \
+)
+DeprecatedVaultMissingPathMessage = (
+    "Vault secrets must now specify the `path` property. The `key` property "
+    "is now a key of a Vault secret rather than the actual path. For "
+    "instance: "
+    "{'my-key': {'type': 'vault', 'key': 'foo'}} "
+    "now becomes: "
     "{'my-key': {'type': 'vault', 'path': 'foo'}}"
+)
 
 
 def warn_about_deprecated_features(experiment: Experiment):
@@ -29,7 +30,7 @@ def warn_about_deprecated_features(experiment: Experiment):
     """
     warned_deprecations = {
         DeprecatedDictArgsMessage: False,
-        DeprecatedVaultMissingPathMessage: False
+        DeprecatedVaultMissingPathMessage: False,
     }
     activities = get_all_activities_in_experiment(experiment)
 
@@ -41,8 +42,9 @@ def warn_about_deprecated_features(experiment: Experiment):
         provider_type = provider.get("type")
         if provider_type == "process":
             arguments = provider.get("arguments")
-            if not warned_deprecations[DeprecatedDictArgsMessage] and \
-                    isinstance(arguments, dict):
+            if not warned_deprecations[DeprecatedDictArgsMessage] and isinstance(
+                arguments, dict
+            ):
                 warned_deprecations[DeprecatedDictArgsMessage] = True
                 warnings.warn(DeprecatedDictArgsMessage, DeprecationWarning)
                 logger.warning(DeprecatedDictArgsMessage)
@@ -53,10 +55,8 @@ def warn_about_deprecated_features(experiment: Experiment):
         for (key, value) in keys.items():
             if isinstance(value, dict) and value.get("type") == "vault":
                 if "key" in value and "path" not in value:
-                    warned_deprecations[
-                        DeprecatedVaultMissingPathMessage] = True
-                    warnings.warn(
-                        DeprecatedVaultMissingPathMessage, DeprecationWarning)
+                    warned_deprecations[DeprecatedVaultMissingPathMessage] = True
+                    warnings.warn(DeprecatedVaultMissingPathMessage, DeprecationWarning)
                     logger.warning(DeprecatedVaultMissingPathMessage)
 
 
