@@ -7,7 +7,7 @@ import pytest
 import yaml
 
 from chaoslib import convert_vars, merge_vars
-from chaoslib.configuration import load_configuration
+from chaoslib.configuration import load_configuration, load_dynamic_configuration
 from chaoslib.exceptions import InvalidExperiment
 
 
@@ -26,6 +26,29 @@ def test_should_load_configuration():
     assert config["token3"] == "value3"
 
 
+@patch("chaoslib.activity.run_activity")
+def test_should_load_dynamic_configuration(activity_mocked):
+    activity_mocked.return_value = "value2"
+    config = load_dynamic_configuration(
+        {
+            "token1": "value1",
+            "token2": {
+                "name": "some probe",
+                "type": "probe",
+                "provider": {
+                    "type": "python",
+                    "module": "tests.fixtures.configuration",
+                    "func": "dynamic_config",
+                    "arguments": {},
+                },
+            },
+        }
+    )
+
+    assert config["token1"] == "value1"
+    assert config["token2"] == "value2"
+
+
 @patch.dict("os.environ", {"KUBE_TOKEN": "value2"})
 def test_should_load_configuration_with_empty_string_as_default():
     config = load_configuration(
@@ -280,3 +303,22 @@ def test_that_environment_variables_are_typed_correctly():
     assert config["token3"] == int(1000)
     assert config["token4"] == 30.54321
     assert config["token5"] == b"these_are_bytes"
+
+
+def test_dynamic_configuration_exception_means_output_is_missing():
+    config = load_dynamic_configuration(
+        {
+            "somekey": "hello world",
+            "token": {
+                "type": "probe",
+                "provider": {
+                    "type": "python",
+                    "module": "fixtures.configprobe",
+                    "func": "raise_exception",
+                },
+            },
+        }
+    )
+
+    assert config["somekey"] == "hello world"
+    assert "token" not in config
